# pynapl

**Python Native Automation Package Library**

The Tastiest Code You May Ever Consume 

## Overview
**pynapl** is the conglomeration of useful tactics that I have made work for my personal and professional automation. The hope is for **pynapl** to evolve and become something more (someday - Exeggutor!!!). 

## NEVER TESTED ON REAL FRUIT
No warranties. No guarantees. But feel free to enjoy as you please. 

### License

**pynapl** is registered under the MIT license - That means if you use it, mention me and we're cool.

